        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260517 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260517 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 34 <strong>control</strong><br>0,2,6,7,8,10,12,13,14,15,16,18,19,20,21,22,23,25,26,30,31,32,33,34,36,38,39,40,41,42,43,45,46,49';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260517 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>5</strong> miembros: 17 <br>1,3,4,5,9,11,17,24,27,28,29,35,37,44,47,48,50';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260517 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260517 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 34 <strong>control</strong><br>0,2,6,7,8,10,12,13,14,15,16,18,19,20,21,22,23,25,26,30,31,32,33,34,36,38,39,40,41,42,43,45,46,49';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260517 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>5</strong> miembros: 17 <br>1,3,4,5,9,11,17,24,27,28,29,35,37,44,47,48,50';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260517 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260517 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 34 <strong>control</strong><br>0,2,6,7,8,10,12,13,14,15,16,18,19,20,21,22,23,25,26,30,31,32,33,34,36,38,39,40,41,42,43,45,46,49';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260517 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>5</strong> miembros: 17 <br>1,3,4,5,9,11,17,24,27,28,29,35,37,44,47,48,50';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260517 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260517 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 34 <strong>control</strong><br>0,2,6,7,8,10,12,13,14,15,16,18,19,20,21,22,23,25,26,30,31,32,33,34,36,38,39,40,41,42,43,45,46,49';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260517 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>5</strong> miembros: 17 <br>1,3,4,5,9,11,17,24,27,28,29,35,37,44,47,48,50';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260517 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260517 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 34 <strong>control</strong><br>0,2,6,7,8,10,12,13,14,15,16,18,19,20,21,22,23,25,26,30,31,32,33,34,36,38,39,40,41,42,43,45,46,49';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260517 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>5</strong> miembros: 17 <br>1,3,4,5,9,11,17,24,27,28,29,35,37,44,47,48,50';}
}
